==> dcl-c_5.3-1.tar.gz: dcl-c-5.3/src/grph1/slpack/slpwwc.c <==
/* src/grph1/slpack/slpwwc.f -- translated by f2c (version 20020621).
   You must link the resulting object file with the libraries:
	-lf2c -lm   (in that order)
*/

#include "libtinyf2c.h"

/* Table of constant values */

static integer c__1 = 1;

/* ----------------------------------------------------------------------- */
/*     SLPWWC : PLOT WORKSTATION-WINDOW CORNER MARKS */
/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int slpwwc_(integer *index, real *rc)
{
    /* System generated locals */
    real r__1;

    /* Local variables */
    static integer itr;
    static real rxmin, rymin, rxmax, rymax, wxmin, wymin, wxmax, wymax;
    extern /* Subroutine */ int msgdmp_(char *, char *, char *, ftnlen, 
	    ftnlen, ftnlen), szcllr_(void), szpllr_(real *, real *), szslti_(
	    integer *, integer *), szoplr_(void), szmvlr_(real *, real *), 
	    stqwtr_(real *, real *, real *, real *, real *, real *, real *, 
	    real *, integer *);

    if (*index <= 0) {
	if (*index == 0) {
	    msgdmp_("M", "SLPWWC", "LINE INDEX IS ZERO / DO NOTHING.", (
		    ftnlen)1, (ftnlen)6, (ftnlen)32);
	    return 0;
	} else {
	    msgdmp_("E", "SLPWWC", "LINE INDEX IS LESS THAN ZERO.", (ftnlen)1,
		     (ftnlen)6, (ftnlen)29);
	}
    }
    if (*rc <= 0.f) {
	if (*rc == 0.f) {
	    msgdmp_("E", "SLPWWC", "LENGTH OF CORNER MARKS IS ZERO / DO NOTH"
		    "ING.", (ftnlen)1, (ftnlen)6, (ftnlen)44);
	    return 0;
	} else {
	    msgdmp_("E", "SLPWWC", "LENGTH OF CORNER MARKS IS LESS THAN ZERO."
		    , (ftnlen)1, (ftnlen)6, (ftnlen)41);
	}
    }
    stqwtr_(&rxmin, &rxmax, &rymin, &rymax, &wxmin, &wxmax, &wymin, &wymax, &
	    itr);
    szslti_(&c__1, index);
    szoplr_();
    r__1 = rymin + *rc;
    szmvlr_(&rxmin, &r__1);
    szpllr_(&rxmin, &rymin);
    r__1 = rxmin + *rc;
    szpllr_(&r__1, &rymin);
    szcllr_();
    szoplr_();
    r__1 = rxmax - *rc;
    szmvlr_(&r__1, &rymin);
    szpllr_(&rxmax, &rymin);
    r__1 = rymin + *rc;
    szpllr_(&rxmax, &r__1);
    szcllr_();
    szoplr_();
    r__1 = rymax - *rc;
    szmvlr_(&rxmax, &r__1);
    szpllr_(&rxmax, &rymax);
    r__1 = rxmax - *rc;
    szpllr_(&r__1, &rymax);
    szcllr_();
    szoplr_();
    r__1 = rxmin + *rc;
    szmvlr_(&r__1, &rymax);
    szpllr_(&rxmin, &rymax);
    r__1 = rymax - *rc;
    szpllr_(&rxmin, &r__1);
    szcllr_();
    return 0;
} /* slpwwc_ */

==> dcl-c_5.3.3.orig.tar.gz: dcl-c-5.3.3/src/grph1/slpack/slpwwc.c <==
/*  -- translated by f2c (version 20050501).
   You must link the resulting object file with libf2c:
	on Microsoft Windows system, link with libf2c.lib;
	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
	or, if you install libf2c.a in a standard place, with -lf2c -lm
	-- in that order, at the end of the command line, as in
		cc *.o -lf2c -lm
	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,

		http://www.netlib.org/f2c/libf2c.zip
*/

#include "libtinyf2c.h"

/* Table of constant values */

static integer c__1 = 1;

/* ----------------------------------------------------------------------- */
/*     SLPWWC : PLOT WORKSTATION-WINDOW CORNER MARKS */
/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int slpwwc_(integer *index, real *rc)
{
    /* System generated locals */
    real r__1;

    /* Local variables */
    static integer itr;
    static real rxmin, rymin, rxmax, rymax, wxmin, wymin, wxmax, wymax;
    extern /* Subroutine */ int msgdmp_(char *, char *, char *, ftnlen, 
	    ftnlen, ftnlen), szcllr_(void), szpllr_(real *, real *), szslti_(
	    integer *, integer *), szoplr_(void), szmvlr_(real *, real *), 
	    stqwtr_(real *, real *, real *, real *, real *, real *, real *, 
	    real *, integer *);

    if (*index <= 0) {
	if (*index == 0) {
	    msgdmp_("M", "SLPWWC", "LINE INDEX IS ZERO / DO NOTHING.", (
		    ftnlen)1, (ftnlen)6, (ftnlen)32);
	    return 0;
	} else {
	    msgdmp_("E", "SLPWWC", "LINE INDEX IS LESS THAN ZERO.", (ftnlen)1,
		     (ftnlen)6, (ftnlen)29);
	}
    }
    if (*rc <= 0.f) {
	if (*rc == 0.f) {
	    msgdmp_("E", "SLPWWC", "LENGTH OF CORNER MARKS IS ZERO / DO NOTH"
		    "ING.", (ftnlen)1, (ftnlen)6, (ftnlen)44);
	    return 0;
	} else {
	    msgdmp_("E", "SLPWWC", "LENGTH OF CORNER MARKS IS LESS THAN ZERO."
		    , (ftnlen)1, (ftnlen)6, (ftnlen)41);
	}
    }
    stqwtr_(&rxmin, &rxmax, &rymin, &rymax, &wxmin, &wxmax, &wymin, &wymax, &
	    itr);
    szslti_(&c__1, index);
    szoplr_();
    r__1 = rymin + *rc;
    szmvlr_(&rxmin, &r__1);
    szpllr_(&rxmin, &rymin);
    r__1 = rxmin + *rc;
    szpllr_(&r__1, &rymin);
    szcllr_();
    szoplr_();
    r__1 = rxmax - *rc;
    szmvlr_(&r__1, &rymin);
    szpllr_(&rxmax, &rymin);
    r__1 = rymin + *rc;
    szpllr_(&rxmax, &r__1);
    szcllr_();
    szoplr_();
    r__1 = rymax - *rc;
    szmvlr_(&rxmax, &r__1);
    szpllr_(&rxmax, &rymax);
    r__1 = rxmax - *rc;
    szpllr_(&r__1, &rymax);
    szcllr_();
    szoplr_();
    r__1 = rxmin + *rc;
    szmvlr_(&r__1, &rymax);
    szpllr_(&rxmin, &rymax);
    r__1 = rymax - *rc;
    szpllr_(&rxmin, &r__1);
    szcllr_();
    return 0;
} /* slpwwc_ */
